@@ -251,7 +251,7 @@ def root():
 @click.option('-t', '--target', type=str)
 def config(api_key, source, target):
     """Show and set configuration"""
-    if (api_key + source + target).strip() == '':
+    if not (api_key or source or target):
         print(' Source language:\t' + configs['SOURCE'])
         print(' Target languages:\t' + configs['TARGET'])
         print(' Yandex API key:\t' + configs['TRANSLATOR_KEY'])
